@@ -11,16 +11,15 @@ conway <- new("gridModel",
     nb     <- eightneighbours(x)
     surviv <- (x >  0 & (nb %in% parms$srv))
     gener  <- (x == 0 & (nb %in% parms$gen))
-    x      <- as.numeric((surviv + gener) > 0)
-    dim(x) <- dim(init)
+    x <- matrix((surviv + gener) > 0, nrow = nrow(init))
     return(x)
   },
   parms  = list(srv = c(2, 3), gen = 3),
   times  = 1:17,
-  init   = matrix(round(runif(1000)), ncol=40),
+  init   = matrix(round(runif(1000)), ncol = 40),
   solver = "iteration"
 )
 
-plot(sim(conway), axes=FALSE)
+plot(sim(conway), axes = FALSE)
 
 
